@@ -13,7 +13,7 @@ N = 64
 g = svox.N3Tree(N=NN, depth_limit=1000).to(device=device)
 gt = torch.zeros((N, N, N, K), device=device)
 
-g.refine_all(2)
+g.refine(2)
 
 
 print('begin fuzz')
@@ -32,7 +32,7 @@ for i in tqdm(range(5000)):
 
         x, y, z = xyz_to_int(q)
         gt[x, y, z] = vals[0]
-        g.set(q, vals, cuda=True)
+        g.set(q, vals)
 
     # ---
 
@@ -42,11 +42,11 @@ for i in tqdm(range(5000)):
 
     r = g(q, cuda=True)[0]
     err = torch.abs(r - rt).max()
-    worst = max(err, worst)
     if err > 5e-5:
         print(i, err.item(), 'q', q[0].detach().cpu().numpy(),
                 'g', r.detach().cpu().numpy(), 'gt', rt.detach().cpu().numpy(),
                  x, y, z)
         break
+    worst = max(err, worst)
 print('worst', worst)
 
